@@ -1,4 +1,33 @@
-#' A function to make it easier to create dplyr function for disk.frame
+#' Create dplyr function for disk.frame
+#' 
+#' A function to make it easier to create functions like \code{filter}
+#' 
+#' @examples 
+#' 
+#' filter = create_dplyr_mapper(dplyr::filter)
+#' 
+#' #' example: creating a function that keeps only the first and last n row
+#' first_and_last <- function(chunk, n, ...) {
+#'   nr = nrow(chunk)
+#'   print(nr-n+1:nr)
+#'   chunk[c(1:n, (nr-n+1):nr), ]
+#' }
+#' 
+#' #' create the function for use with disk.frame
+#' first_and_last_df = create_dplyr_mapper(first_and_last)
+#' 
+#' mtcars.df = as.disk.frame(mtcars)
+#' 
+#' #' the operation is lazy
+#' lazy_mtcars.df = mtcars.df %>%
+#'   first_and_last_df(2)
+#' 
+#' #' bring into R
+#' collect(lazy_mtcars.df)
+#' 
+#' #' clean up
+#' delete(mtcars.df)
+#' 
 #' @param dplyr_fn The dplyr function to create a mapper for
 #' @param warning_msg The warning message to display when invoking the mapper
 #' @importFrom rlang enquos quo
@@ -44,6 +73,7 @@ create_dplyr_mapper <- function(dplyr_fn, warning_msg = NULL) {
 #' @param ... Same as the dplyr functions
 #' @param .data a disk.frame
 #' @rdname dplyr_verbs
+#' @family dplyr verbs
 #' @examples
 #' library(dplyr)
 #' library(magrittr)
@@ -69,29 +99,35 @@ select.disk.frame <- function(.data, ...) {
 }
 
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 rename.disk.frame <- create_dplyr_mapper(dplyr::rename)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 filter.disk.frame <- create_dplyr_mapper(dplyr::filter)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr filter_all
 filter_all.disk.frame <- create_dplyr_mapper(dplyr::filter_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr filter_if
 filter_if.disk.frame <- create_dplyr_mapper(dplyr::filter_if)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr filter_at
 filter_at.disk.frame <- create_dplyr_mapper(dplyr::filter_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom future getGlobalsAndPackages
@@ -99,142 +135,165 @@ filter_at.disk.frame <- create_dplyr_mapper(dplyr::filter_at)
 #' @importFrom dplyr mutate
 mutate.disk.frame <- create_dplyr_mapper(dplyr::mutate)
 
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr transmute
 #' @rdname dplyr_verbs
 transmute.disk.frame <- create_dplyr_mapper(dplyr::transmute)
 
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr arrange
 #' @rdname dplyr_verbs
 arrange.disk.frame <- create_dplyr_mapper(dplyr::arrange, "disk.frame only sorts (arange) WITHIN each chunk")
 
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr summarise
 #' @rdname dplyr_verbs
 summarise.disk.frame <- create_dplyr_mapper(dplyr::summarise)
 
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr tally
 #' @rdname dplyr_verbs
 tally.disk.frame <- create_dplyr_mapper(dplyr::tally)
 
-#' @export
-#' @importFrom dplyr tally
-#' @rdname dplyr_verbs
-tally.disk.frame <- create_dplyr_mapper(dplyr::tally)
-
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr count
 #' @rdname dplyr_verbs
 count.disk.frame <- create_dplyr_mapper(dplyr::count)
 
+# TODO alot of these .disk.frame functions are not generic
+
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr add_count
 #' @rdname dplyr_verbs
 add_count.disk.frame <- create_dplyr_mapper(dplyr::add_count)
 
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr add_tally
 #' @rdname dplyr_verbs
 add_tally.disk.frame <- create_dplyr_mapper(dplyr::add_tally)
 
-
+#' @family dplyr verbs
 #' @export
 #' @importFrom dplyr summarize
 #' @rdname dplyr_verbs
 summarize.disk.frame <- create_dplyr_mapper(dplyr::summarize)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr do
 do.disk.frame <- create_dplyr_mapper(dplyr::do)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr group_by_all
 group_by_all.disk.frame <- create_dplyr_mapper(dplyr::group_by_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr group_by_at
 group_by_at.disk.frame <- create_dplyr_mapper(dplyr::group_by_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr group_by_if
 group_by_if.disk.frame <- create_dplyr_mapper(dplyr::group_by_if)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr mutate_all
 mutate_all.disk.frame <- create_dplyr_mapper(dplyr::mutate_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr mutate_at
 mutate_at.disk.frame <- create_dplyr_mapper(dplyr::mutate_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr mutate_if
 mutate_if.disk.frame <- create_dplyr_mapper(dplyr::mutate_if)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr rename_all
 rename_all.disk.frame <- create_dplyr_mapper(dplyr::rename_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr rename_at
 rename_at.disk.frame <- create_dplyr_mapper(dplyr::rename_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr rename_if
 rename_if.disk.frame <- create_dplyr_mapper(dplyr::rename_if)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr select_all
 select_all.disk.frame <- create_dplyr_mapper(dplyr::select_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr select_at
 select_at.disk.frame <- create_dplyr_mapper(dplyr::select_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr select_if
 select_if.disk.frame <- create_dplyr_mapper(dplyr::select_if)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarise_all
 summarise_all.disk.frame <- create_dplyr_mapper(dplyr::summarise_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarise_at
 summarise_at.disk.frame <- create_dplyr_mapper(dplyr::summarise_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarize
 summarize.disk.frame <- create_dplyr_mapper(dplyr::summarize)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarize_all
 summarize_all.disk.frame <- create_dplyr_mapper(dplyr::summarize_all)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarize_at
 summarize_at.disk.frame <- create_dplyr_mapper(dplyr::summarize_at)
 
+#' @family dplyr verbs
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom dplyr summarize_if
@@ -258,6 +317,7 @@ groups.disk.frame <- function(x){
 #' @param .data a disk.frame
 #' @param ... same as the dplyr::group_by
 #' @export
+#' @family dplyr verbs
 #' @rdname group_by
 # TODO check shardkey
 group_by.disk.frame <- function(.data, ...) {
@@ -321,7 +381,7 @@ play <- function(.data, cmds=NULL){
           assign(ng[i], g, pos = an_env)
         }
       }
-      .data <- do.call(cmd$func, list(.data), envir = an_env)
+      .data <- do.call(cmd$func, c(list(.data),cmd$dotdotdot), envir = an_env)
     }
   }
   .data
